package org.opengroup.osdu.legal.tags.dto;

import org.junit.BeforeClass;
import org.junit.Test;

import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import static junit.framework.TestCase.assertEquals;

public class RequestLegalTagsTests {

    private static Validator validator;

    @BeforeClass
    public static void setup() {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    }

    @Test
    public void should_haveValidationError_when_requestingMoreThan25LegalTags(){

        RequestLegalTags requestLegalTags = new RequestLegalTags();
        List<String> names = new ArrayList<>();
        for(int i = 0; i < 26; i++){
            names.add("12345");
        }
        requestLegalTags.setNames(names);
        Set<ConstraintViolation<RequestLegalTags>> violations = validator.validate(requestLegalTags);

        assertEquals(1, violations.size());
    }

    @Test
    public void should_haveValidationError_when_nullASsignedToLegalTagNames(){

        RequestLegalTags requestLegalTags = new RequestLegalTags();
        requestLegalTags.setNames(null);
        Set<ConstraintViolation<RequestLegalTags>> violations = validator.validate(requestLegalTags);

        assertEquals(1, violations.size());
    }

    @Test
    public void should_haveNoValidationError_when_requesting20LegalTags(){

        RequestLegalTags requestLegalTags = new RequestLegalTags();
        List<String> names = new ArrayList<>();
        for(int i = 0; i < 20; i++){
            names.add("12345");
        }
        requestLegalTags.setNames(names);
        Set<ConstraintViolation<RequestLegalTags>> violations = validator.validate(requestLegalTags);

        assertEquals(0, violations.size());
    }

    @Test
    public void should_haveValidationErrors_when_requestingLegalTagsUsingInvalidName(){

        RequestLegalTags requestLegalTags = new RequestLegalTags();
        List<String> names = new ArrayList<>();
        names.add("12345+");

        requestLegalTags.setNames(names);
        Set<ConstraintViolation<RequestLegalTags>> violations = validator.validate(requestLegalTags);

        assertEquals(1, violations.size());
    }
}
