package org.opengroup.osdu.legal.tags.util;

import com.google.rpc.Code;

import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.core.common.model.legal.PersistenceException;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.junit.MockitoJUnitRunner;
import org.opengroup.osdu.core.common.logging.JaxRsDpsLog;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

@RunWith(MockitoJUnitRunner.class)
public class PersistenceExceptionToAppExceptionMapperTests {
    @Mock
    private JaxRsDpsLog log;

    @InjectMocks
    private PersistenceExceptionToAppExceptionMapper sut;


    @Test
    public void should_returnFunctionsValue_When_RunningGivenFunction(){

        String result = sut.run((String s) -> "hi " + s, "world", "reason");

        assertEquals("hi world", result);
    }


    @Test
    public void shouldthrowAppException404_When_RunningFunctionThrowsPersistenceExceptionNotFound(){

        try {
            sut.run((String s) -> {throw new PersistenceException(Code.NOT_FOUND_VALUE, "a", null); } ,"world", "reason");
            fail("Should have thrown exception");
        }
        catch(AppException e){
            assertEquals(404, e.getError().getCode());
            assertEquals("reason", e.getError().getReason());
            assertEquals("Not found.", e.getError().getMessage());
        }
    }

    @Test
    public void shouldthrowAppException400_When_RunningFunctionThrowsPersistenceExceptionInvalidArgument(){

        try {
            sut.run((String s) -> {throw new PersistenceException(Code.INVALID_ARGUMENT_VALUE, "a", null); } ,"world", "reason");
            fail("Should have thrown exception");
        }
        catch(AppException e){
            assertEquals(400, e.getError().getCode());
            assertEquals("reason", e.getError().getReason());
            assertEquals("Invalid argument given.", e.getError().getMessage());
        }
    }

    @Test
    public void shouldthrowAppException500_When_RunningFunctionThrowsDatastoreExceptAborted(){

        try {
            sut.run((String s) -> { throw new PersistenceException(Code.ABORTED_VALUE, "a", null); },"world", "reason");
            fail("Should have thrown exception");
        }
        catch(AppException e){
            assertEquals(500, e.getError().getCode());
            assertEquals("reason", e.getError().getReason());
            assertEquals("Unexpected error. Please wait 30 seconds and try again.", e.getError().getMessage());
        }
    }
}
